@@ -160,12 +160,10 @@ class ControlBase(object):
             raise ValueError("Cannot handle input states for is_reduced=True")
         # Initializations 
         state_names = self.state_names
-        # FIXME: remove "if False"
-        if False:
-            # Don't delete input_names that are state
-            state_names = list(set(self.state_names).difference(self.input_names))
-            state_names = sorted(state_names,
-                  key=lambda n: self.state_names.index(n))
+        # Delete states that are inputs
+        state_names = list(set(self.state_names).difference(self.input_names))
+        state_names = sorted(state_names,
+              key=lambda n: self.state_names.index(n))
         num_state = len(state_names)
         num_output = len(self.output_names)
         if len(set(self.reaction_names).intersection(self.output_names)) > 0:
@@ -187,9 +185,9 @@ class ControlBase(object):
                 C_T_dct[name] = values
             elif name in self.species_names:
                 if L0_df is None:
-                    raise RuntimeError("Species missing from L0")
+                    raise RuntimeError("Species missing from L0: %s" % name)
                 if not name in L0.rownames:
-                    raise RuntimeError("Species missing from L0")
+                    raise RuntimeError("Species missing from L0: %s" % name)
                 C_T_dct[name] = L0_df.loc[name, :]
             elif name in self.reaction_names:
                 C_T_dct[name] = flux_jacobian_df.loc[name, :]
@@ -474,12 +472,8 @@ class ControlBase(object):
             # Construct the matrix for species inputs
             if len(species_inputs) > 0:
                 jacobian_df = self.getJacobian(time=time)
-                # FIXME: remove "if False"
-                if False:
-                    # Don't address state for input species
-                    df = jacobian_df.drop(species_inputs, axis=0)
-                else:
-                    df = jacobian_df
+                # Don't include states that are input species
+                df = jacobian_df.drop(species_inputs, axis=0)
                 B_species_df = df[species_inputs]
                 B_df = B_species_df
             if len(reaction_inputs) > 0:
@@ -534,8 +528,8 @@ class ControlBase(object):
               and (C_mat is None)  and (D_mat is None)
         inputs_and_outputs = set(self.input_names).union(self.output_names)
         is_subset_state = inputs_and_outputs <= set(self.state_names)
-        #
-        if (not self.is_reduced) and is_default_matrices and is_subset_state:
+        # FIXME: Delete?
+        if False and (not self.is_reduced) and is_default_matrices and is_subset_state:
             cur_time = self.getTime()
             if time != self.getTime():
                 self.setTime(time)
@@ -560,13 +554,11 @@ class ControlBase(object):
             A_df = self.getJacobian(time)
             columns = A_df.columns
             # Remove any state that's an input
-            # FIXME: remove "if False"
-            if False:
-                # Allow state to be generated internally
-                for name in self.input_names:
-                    if name in columns:
-                        A_df = A_df.drop(name, axis=0)
-                        A_df = A_df.drop(name, axis=1)
+            # Allow state to be generated internally
+            for name in self.input_names:
+                if name in columns:
+                    A_df = A_df.drop(name, axis=0)
+                    A_df = A_df.drop(name, axis=1)
             A_mat = A_df.values
         #
         if B_mat is None:
