@@ -117,7 +117,7 @@ class NonlinearIOSystem(control.NonlinearIOSystem):
                      for i, n in enumerate(self.input_names)}
         for input_name, input_value in input_dct.items():
             try:
-                self.ctlsb.add({input_name: input_value})
+                self.ctlsb.set({input_name: float(input_value)})
             except RuntimeError:
                 if input_name not in self._ignored_inputs:
                     self._ignored_inputs.append(input_name)
@@ -129,7 +129,7 @@ class NonlinearIOSystem(control.NonlinearIOSystem):
         dstate_ser = pd.Series(self.ctlsb.get(dstate_names))
         return dstate_ser.values
 
-    def _outfcn(self, _, x_vec, __, ___):
+    def _outfcn(self, time, x_vec, __, ___):
         """
         Calculates the values of outputs.
 
